#
# spec file for package rasdaemon
#
# Copyright (c) 2018 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rasdaemon
Version:        0.6.0
Release:        lp150.4.3.1
Summary:        Utility to receive RAS error tracings
License:        GPL-2.0
Group:          Hardware/Other
Url:            http://git.infradead.org/users/mchehab/rasdaemon.git
Source:         %{name}-%{version}.tar.xz
Patch0:         fix_aer_error_type.patch
Patch1:         avoid_writing_at_end_of_buffer.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-devel
BuildRequires:  libtool
BuildRequires:  sqlite3-devel
BuildRequires:  systemd-rpm-macros
%ifnarch s390x ppc64le
Requires:       dmidecode
%endif
Requires:       perl-DBD-SQLite
%{?systemd_requires}

%description
rasdaemon is a RAS (Reliability, Availability and Serviceability) logging tool.
It currently records memory errors, using the EDAC tracing events.
EDAC is drivers in the Linux kernel that handle detection of ECC errors
from memory controllers for most chipsets on i386 and x86_64 architectures.
EDAC drivers for other architectures like arm also exists.
This userspace component consists of an init script which makes sure
EDAC drivers and DIMM labels are loaded at system startup, as well as
an utility for reporting current error counts from the EDAC sysfs files.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -fvi
%configure \
  --enable-mce \
  --enable-aer \
  --enable-sqlite3 \
  --enable-extlog \
  --enable-abrt-report \
  --enable-arm \
  --enable-non-standard

make %{?_smp_mflags} V=1

%install
%make_install
install -D -p -m 0644 misc/rasdaemon.service %{buildroot}%{_unitdir}/rasdaemon.service
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcrasdaemon
install -D -p -m 0644 misc/ras-mc-ctl.service %{buildroot}%{_unitdir}/ras-mc-ctl.service
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcras-mc-ctl
install -D -p -m 0644 labels/dell %{buildroot}%{_sysconfdir}/ras/dimm_labels.d/dell
rm %{buildroot}%{_includedir}/*.h
mkdir -p %{buildroot}%{_localstatedir}/lib/rasdaemon

%pre
%service_add_pre rasdaemon.service ras-mc-ctl.service

%post
%service_add_post rasdaemon.service ras-mc-ctl.service

%preun
%service_del_preun rasdaemon.service ras-mc-ctl.service

%postun
%service_del_postun rasdaemon.service ras-mc-ctl.service

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README TODO
%{_sbindir}/rasdaemon
%{_sbindir}/ras-mc-ctl
%{_sbindir}/rcrasdaemon
%{_sbindir}/rcras-mc-ctl
%{_mandir}/*/*
%{_unitdir}/*.service
%dir %{_sysconfdir}/ras
%dir %{_localstatedir}/lib/rasdaemon
%ghost %{_localstatedir}/lib/rasdaemon/ras-mc_event.db
%config %{_sysconfdir}/ras/dimm_labels.d

%changelog
* Thu Mar  7 2019 trenn@suse.de
- Fix AMD K8 bad buffer access and a fix using correct PCI AER type
  bsc#1128122
  Bug 1128122 - rasdaemon update with fixes on mce-amd-k8 and PCIe AER error
  type
  A fix_aer_error_type.patch
  mainline commit: 0a16789f4557d3423138ba
  A avoid_writing_at_end_of_buffer.patch
  mainline commit: 54a74d94ac0c296c24e66e
* Thu Apr  5 2018 josef.moellers@suse.com
- Enabled arm and non-standard.
  [bsc#1086520, FATE#323658]
* Wed Jan 17 2018 josef.moellers@suse.com
- Do not require dmidecode on s390x and ppc64le, it does not
  exist there!
  [bsc#1071830]
* Tue Nov 21 2017 eich@suse.com
- Update to version 0.6.0:
  * rasdaemon: Update DIMM labels for Intel Skylake servers
  * rasdaemon:add support for non-standard error decoder
  * rasdaemon:add support for Hisilicon non-standard error decoder
  * configure.ac: show if Hisilicon error report are enabled
  * rasdaemon: add support for ARM events
  * configure.ac: display if ARM error report is enabled
  * rasdaemon: update bugs report information
  * Makefile: add new rasdaemon headers
  * rasdaemon.spec: add other --enable options
  * Bump to version 0.6.0
  (FATE#323162).
* Fri Jun  9 2017 fschnizlein@suse.com
- Update to version 0.5.9:
  * Update it to point to the new repository
  * configure.ac: report enabled features
  * rasdaemon: Update DIMM labels for Dell Servers
  * rasdaemon: add Knights Mill model
  * rasdaemon.spec.in: update it to reflect current needs
* Mon Apr 10 2017 mpluskal@suse.com
- Switch to _service as fedorahosted is retired
- Update project url
- Use macro for systemd dependencies
- Make building more verbose
- Install provided labels for dell
* Tue May 31 2016 fvogt@suse.com
- Update to 0.5.8, obsoleted patches:
  - broadwell_de_mscod.patch
  - broadwell_ep_ex_mscod.patch
* Tue May 31 2016 trenn@suse.de
- Add MSCOD values for broadwell de/ep/ex processors
  * Add broadwell_de_mscod.patch
  * Add broadwell_ep_ex_mscod.patch
* Mon Mar  7 2016 fvogt@suse.com
- Run spec-cleaner: - Change Group and copyright notice
* Mon Mar  7 2016 trenn@suse.de
- Update to version 0.5.7 (including Knights Landing CPU support, fate#319513)
* Fri Nov 27 2015 fvogt@suse.com
- Use provided .tar.xz directly instead of generating one via tar_scm
* Wed Nov 25 2015 trenn@suse.de
- Fix upper case letter issues on requires on package perl-DBD-SQLite
- Create /var/lib/rasdaemon for db file creation at runtime
* Fri Nov  6 2015 fvogt@suse.com
- Disable _service and run manually
* Tue Nov  3 2015 fvogt@suse.com
- Initial commit from git
